#!/bin/bash

readonly VERSION="copy system log V1.0.0"
readonly PROG="$(basename "$0")"
readonly LOG_TAG='fibocom-log-capture'
readonly KERNEL_VERSION=`uname -r`
readonly BITS=`uname -m`
readonly DATE=`date +%Y_%m_%d_%H_%M_%S`
readonly TLOG=`ps -ef |grep tlog | awk 'NR==1{print}' | awk '{print $2}'`
readonly AT_PORT=`ls /dev/ttyACM* | awk 'NR==1{print}'`
readonly TRACE_PORT=`ls /dev/ttyACM* | awk 'NR==2{print}'`
COREDUMP_CONFIG_LOG_NAME="coredump_config.log"
OPEN_TRACE_CONFIG_LOG_NAME="open_trace_config.log"
DATE_FILE="/tmp/fibocom_date"
RUN_MODE="0"
log_info() {
  logger -t "${LOG_TAG}" --id="$$" -p info "$*"
  echo "   INFO: $*" > /dev/stderr
}

log_warning() {
  logger -t "${LOG_TAG}" --id="$$" -p warn "$*"
  echo "WARNING: $*" > /dev/stderr
}

log_error() {
  logger -t "${LOG_TAG}" --id="$$" -p err "$*"
  echo "  ERROR: $*" > /dev/stderr
}

die() {
  log_warning "$@"
  exit 1
}

install_drivers() {
    insmod /lib/modules/$1/kernel/drivers/usb/mon/usbmon.ko
}
create_logsave_dir(){
    mkdir -p $PWD/log/$1
}
capture_dump(){
   $PWD/bin/sttcli -c -a $1 -p $PWD/log/$DATE/coredump/  >> $PWD/log/$DATE/coredump/coredump.log 2>&1
}
capture_sys(){
   cp -r /var/log/net* $PWD/log/$1/ >> $PWD/log/$DATE/basic.log 2>&1
   cp -r /var/log/messages* $PWD/log/$1/ >> $PWD/log/$DATE/basic.log  2>&1
   cp -r /var/log/kern.log $PWD/log/$1/ >> $PWD/log/$DATE/basic.log 2>&1
   cp -r /var/log/syslog $PWD/log/$1/ >> $PWD/log/$DATE/basic.log 2>&1
   #copy fwswitch log
   cp -r /opt/fibocom/Fibocom_DownLoad.log $PWD/log/$1/ >> $PWD/log/$DATE/basic.log 2>&1
   #copy coredump config log
   cp -rf $PWD/log/$COREDUMP_CONFIG_LOG_NAME $PWD/log/$1/ >> $PWD/log/$DATE/basic.log 2>&1
   #copy opentrace config log
   cp -rf $PWD/log/$OPEN_TRACE_CONFIG_LOG_NAME $PWD/log/$1/ >> $PWD/log/$DATE/basic.log 2>&1
}
clean_syslog(){
  echo > /var/log/kern.log
  echo > /var/log/syslog
}
kill_lastthread(){
  killall tlog >> $PWD/log/$DATE/basic.log 2>&1
  killall sttcli >> $PWD/log/$DATE/basic.log 2>&1
  killall tcpdump >> $PWD/log/$DATE/basic.log 2>&1
  kill `ps -ef |grep tlog | awk 'NR==1{print}' | awk '{print $2}'`   >> $PWD/log/$DATE/basic.log 2>&1
  kill `ps -ef |grep sttcli | awk 'NR==1{print}' | awk '{print $2}'`   >> $PWD/log/$DATE/basic.log 2>&1
  kill `ps -ef |grep tcpdump | awk 'NR==1{print}' | awk '{print $2}'`  >> $PWD/log/$DATE/basic.log 2>&1
  kill `ps -ef |grep tcpdump | awk 'NR==1{print}' | awk '{print $2}'`  >> $PWD/log/$DATE/basic.log 2>&1
}
kill_stt(){
  kill `ps -ef |grep tlog | awk 'NR==1{print}' | awk '{print $2}'` >> $PWD/log/$DATE/basic.log 2>&1
}
open_trace(){
echo -e "at+trace=1\r\n" > $1
}
open_mmcli_debug(){
 mmcli --set-logging=DEBUG
}
chmod_all_file_mod(){
 chmod 777 -R *
 chmod 777 /dev/ttyACM*
}
main() {
    echo "$VERSION"
    if [ `whoami` != "root" ];then
        echo "only root can run me"
        exit 1
    fi


    echo ${DATE} > ${DATE_FILE}
    create_logsave_dir "${DATE}"
    chmod_all_file_mod
    echo "$KERNEL_VERSION $BITS $VERSION" >> $PWD/log/$DATE/basic.log
    echo "$VERSION" >> $PWD/log/$DATE/basic.log
    echo "tcpdump version:" >> $PWD/log/$DATE/basic.log
    ./bin/tcpdump --version >> $PWD/log/$DATE/basic.log
    echo "sttcli version:" >> $PWD/log/$DATE/basic.log
    ./bin/sttcli -v >> $PWD/log/$DATE/basic.log
    echo "tlog version:" >> $PWD/log/$DATE/basic.log
    ./bin/tlog -v >> $PWD/log/$DATE/basic.log
    echo "ccom version:" >> $PWD/log/$DATE/basic.log
    ./bin/ccom -v >> $PWD/log/$DATE/basic.log

    capture_sys "${DATE}"
    
    echo "copy finish"
}
main "$@"
