#!/bin/bash

readonly VERSION="CAPTURE_TOOL_V0.30"
readonly PROG="$(basename "$0")"
readonly LOG_TAG='fibocom-log-capture'
readonly KERNEL_VERSION=`uname -r`
readonly BITS=`uname -m`
readonly DATE=`date +%Y_%m_%d_%H_%M_%S`
readonly TLOG=`ps -ef |grep tlog | awk 'NR==1{print}' | awk '{print $2}'`
COREDUMP_CONFIG_LOG_NAME="coredump_config.log"
OPEN_TRACE_CONFIG_LOG_NAME="open_trace_config.log"
DATE_FILE="/tmp/fibocom_date"
log_file="/usr/local/fibocomtools"
modemfwd_cfg_file="/etc/init/modemfwd.conf"
modemfwd_cfg_dir="/opt/google/modemfwd-firmware/"
chromeos_cfg_file="/etc/lsb-release"
RUN_MODE="0"
ftrace_flag="n"
xhci_flag="n"
sttlog_size="1024"
savedir="$PWD"
DiskLimitSize="0.5"
ModemId=$1
DiagPort=$2


usage()
{
    echo   "example:./CaptureLog_Chrome.sh -s 100 -f -x
           option:
          -s <sttlog_size(M)> default size 1024M
          -f             capture ftrace log
          -x             capture xhci log
          -h             help infomation"
}
 

log_info() {
  logger -t "${LOG_TAG}" --id="$$" -p info "$*"
  echo "   INFO: $*" > /dev/stderr
}

log_warning() {
  logger -t "${LOG_TAG}" --id="$$" -p warn "$*"
  echo "WARNING: $*" > /dev/stderr
}

log_error() {
  logger -t "${LOG_TAG}" --id="$$" -p err "$*"
  echo "  ERROR: $*" > /dev/stderr
}

die() {
  log_warning "$@"
  exit 1
}
modemfwd_cfg_check() {
  crossystem |grep fwid >> $log_file/LOG/$DATE/basic.log
  mosys platform sku >> $log_file/LOG/$DATE/basic.log 
  
  if [ ! -f "$modemfwd_cfg_file" ]; then
    echo "$modemfwd_cfg_file is not exist"
  else
	echo "$modemfwd_cfg_file" >> $log_file/LOG/$DATE/basic.log
  fi
  
  if [ ! -d "$modemfwd_cfg_dir" ]; then
    echo "$modemfwd_cfg_dir is not exist"
  else
    for file in ` ls $modemfwd_cfg_dir `
	do
	 echo $file >> $log_file/LOG/$DATE/basic.log
	done
  fi
  
  if test $(pgrep -f modemfwd | wc -l) -eq 0
  then 
   echo "modemfwd is not exist" >> /$log_file/LOG/$DATE/basic.log
  else
   echo "modemfwd is exist" >> /$log_file/LOG/$DATE/basic.log
  fi
} 

open_dynamic_log() {
#create mount diretory
    mkdir /usr/local/debugfs
#mount debugfs
    mount -t debugfs none /usr/local/debugfs

#open dynamic log
    echo -n "module usbcore +p" > /usr/local/debugfs/dynamic_debug/control
    echo -n "module xhci_hcd +p" > /usr/local/debugfs/dynamic_debug/control

#close dynamic log
#echo -n "module usbcore -p" > /usr/local/debugfs/dynamic_debug/control
}

close_dynamic_log() {
#close dynamic log
    echo -n "module usbcore -p" > /usr/local/debugfs/dynamic_debug/control
}

install_drivers() {
    insmod /lib/modules/$1/kernel/drivers/usb/mon/usbmon.ko >> $log_file/LOG/$DATE/basic.log 2>&1
}
create_logsave_dir(){
    mkdir -p $log_file/LOG/$1
}

capture_pcap_unlimit(){
   ../COMMON/bin/tcpdump -i usbmon1 -w $log_file/LOG/$1/usbmon1.pcap -C $2 &
   ../COMMON/bin/tcpdump -i usbmon2 -w $log_file/LOG/$1/usbmon2.pcap -C $2 &
   ../COMMON/bin/tcpdump -i usbmon3 -w $log_file/LOG/$1/usbmon3.pcap -C $2 &
   ../COMMON/bin/tcpdump -i usbmon4 -w $log_file/LOG/$1/usbmon4.pcap -C $2 &
}

capture_pcap_limit(){
   killall auto_remove_oldfile.sh >> $log_file/LOG/$DATE/basic.log 2>&1
   ../COMMON/bin/tcpdump -i usbmon1 -w $log_file/LOG/$1/usbmon1.pcap -C $2 &
   ../COMMON/auto_remove_oldfile.sh $log_file/LOG/$1/usbmon1.pcap >> $log_file/LOG/$DATE/pcapcheck.log 2>&1 &
   ../COMMON/bin/tcpdump -i usbmon2 -w $log_file/LOG/$1/usbmon2.pcap -C $2 &
   ../COMMON/auto_remove_oldfile.sh $log_file/LOG/$1/usbmon2.pcap >> $log_file/LOG/$DATE/pcapcheck.log 2>&1 &
   ../COMMON/bin/tcpdump -i usbmon3 -w $log_file/LOG/$1/usbmon3.pcap -C $2 &
   ../COMMON/auto_remove_oldfile.sh $log_file/LOG/$1/usbmon3.pcap >> $log_file/LOG/$DATE/pcapcheck.log 2>&1 &
   ../COMMON/bin/tcpdump -i usbmon4 -w $log_file/LOG/$1/usbmon4.pcap -C $2 &
   ../COMMON/auto_remove_oldfile.sh $log_file/LOG/$1/usbmon4.pcap >> $log_file/LOG/$DATE/pcapcheck.log 2>&1 &
}
capture_sys(){
   killall auto_remove_oldfile.sh >> $log_file/LOG/$DATE/basic.log 2>&1
   mkdir -p $log_file/LOG/$1/var
   cd /var
   tar zcf log.tar.gz log/
   cd "$savedir"
   cp -rf /var/log.tar.gz $log_file/LOG/$1/var/ >> $log_file/LOG/$DATE/basic.log 2>&1
   rm /var/log.tar.gz
   #copy fwswitch log
   cp -r /opt/fibocom/Fibocom_DownLoad.log $log_file/LOG/$1/ >> $log_file/LOG/$DATE/basic.log 2>&1
   #copy coredump config log
   cp -rf $log_file/LOG/$COREDUMP_CONFIG_LOG_NAME $log_file/LOG/$1/ >> $log_file/LOG/$DATE/basic.log 2>&1
   #copy opentrace config log
   cp -rf $log_file/LOG/$OPEN_TRACE_CONFIG_LOG_NAME $log_file/LOG/$1/ >> $log_file/LOG/$DATE/basic.log 2>&1
   close_modemfwd_debug
  # close_modemfwd_helpers_debug
	if [ "$xhci_flag" == "y" ];then
        close_dynamic_log
	fi
	if [ "$ftrace_flag" == "y" ];then
         close_dynamic_log	
	    ../COMMON/usb-ftrace-stop.sh $DATE
	fi
}
clean_syslog(){
  echo > /var/log/kern.log
  echo > /var/log/syslog
}
kill_lastthread(){
  killall diaggrabpro >> $log_file/LOG/$DATE/basic.log 2>&1
  killall tcpdump >> $log_file/LOG/$DATE/basic.log 2>&1
  killall auto_remove_oldfile.sh >> $log_file/LOG/$DATE/basic.log 2>&1
  kill `ps -ef |grep diaggrabpro | awk 'NR==1{print}' | awk '{print $2}'`   >> $log_file/LOG/$DATE/basic.log 2>&1
  kill `ps -ef |grep tcpdump | awk 'NR==1{print}' | awk '{print $2}'`  >> $log_file/LOG/$DATE/basic.log 2>&1
  kill `ps -ef |grep tcpdump | awk 'NR==1{print}' | awk '{print $2}'`  >> $log_file/LOG/$DATE/basic.log 2>&1
}

open_mmcli_debug(){
 mmcli --set-logging=DEBUG
}

open_modemfwd_debug(){
 mv /etc/init/modemfwd.conf  /etc/init/modemfwd.conf_bak
 cp ../COMMON/modemfwd-helpers/modemfwd.conf  /etc/init/
 restart modemfwd
}

close_modemfwd_debug(){
 rm -f /etc/init/modemfwd.conf
 mv /etc/init/modemfwd.conf_bak  /etc/init/modemfwd.conf
}

open_modemfwd_helpers_debug(){
 mv /opt/google/modemfwd-helpers/helper_manifest.prototxt   /opt/google/modemfwd-helpers/helper_manifest.prototxt_bak
  
  if [ ! -f "$chromeos_cfg_file" ]; then
    echo "$modemfwd_cfg_file is not exist"

  else
    board_line=`cat /etc/lsb-release |grep CHROMEOS_RELEASE_BUILDER_PATH`
    echo "$board_line" > board_newline
    customer=$(cut -d = -f 2 board_newline|cut -d - -f 1)
    rm -rf  board_newline
  fi

  
  if [ "$customer" == "nautilus" ];then
    cp ../COMMON/modemfwd-helpers/naltilus_helper_manifest.prototxt  /opt/google/modemfwd-helpers/helper_manifest.prototxt
    EN_GPIO=432
  elif [ "$customer" == "coral" ];then
    cp ../COMMON/modemfwd-helpers/coral_helper_manifest.prototxt    /opt/google/modemfwd-helpers/helper_manifest.prototxt
    EN_GPIO=395
  elif [ "$customer" == "quanta" ];then
    cp ../COMMON/modemfwd-helpers/quanta_helper_manifest.prototxt   /opt/google/modemfwd-helpers/helper_manifest.prototxt
    EN_GPIO=395
  elif [ "$customer" == "sarien" ];then
    cp ../COMMON/modemfwd-helpers/sarien_helper_manifest.prototxt   /opt/google/modemfwd-helpers/helper_manifest.prototxt
    EN_GPIO=311
  elif [ "$customer" == "drallion" ];then
   cp ../COMMON/modemfwd-helpers/drallion_helper_manifest.prototxt  /opt/google/modemfwd-helpers/helper_manifest.prototxt
    EN_GPIO=466
  elif [ "$customer" == "hatch" ];then
    cp ../COMMON/modemfwd-helpers/hatch_helper_manifest.prototxt    /opt/google/modemfwd-helpers/helper_manifest.prototxt
    EN_GPIO=218
  elif [ "$customer" == "octopus" ];then
    cp ../COMMON/modemfwd-helpers/octopus_helper_manifest.prototxt  /opt/google/modemfwd-helpers/helper_manifest.prototxt
    EN_GPIO=337
  elif [ "$customer" == "dedede" ];then
	cp ../COMMON/modemfwd-helpers/dedede_helper_manifest.prototxt  /opt/google/modemfwd-helpers/helper_manifest.prototxt
	EN_GPIO=349
  elif [ "$customer" == "zork" ];then
	cp ../COMMON/modemfwd-helpers/zork_helper_manifest.prototxt  /opt/google/modemfwd-helpers/helper_manifest.prototxt
	EN_GPIO=345
  else
    echo "$customer customer not support"
  fi
}
close_modemfwd_helpers_debug(){
 rm -f /opt/google/modemfwd-helpers/helper_manifest.prototxt
 mv /opt/google/modemfwd-helpers/helper_manifest.prototxt_bak  /opt/google/modemfwd-helpers/helper_manifest.prototxt
}

chmod_all_file_mod(){
 chmod a+x -R ../*
 chmod 777 /dev/ttyUSB*
}
check_tool(){
 ls /bin/$1 >> /dev/null 2>&1
 if [ $? -ne 0 ];then
	 ls /usr/bin/$1 >> /dev/null 2>&1
	 if [ $? -ne 0 ];then
		 ls /usr/sbin/$1 >> /dev/null 2>&1
		 if [ $? -ne 0 ];then
			 echo "$1 tool not found"
			 return 1
		 fi
	 fi
 fi
 return 0
}


main() {
    echo "$VERSION"
    if [ `whoami` != "root" ];then
        echo "only root can run me"
        exit 1
    fi
    
#usage

#read -p "if you want to capture additional log,please input "y" run "$0" again,otherwise Please input any character and capture log" quit
#if [ "$quit" == "y" ];then
#    exit 1
#fi

while getopts s:fxh: OPTION
do
    case $OPTION in
        s)
            sttlog_size=$OPTARG 
            ;;
        f)
            ftrace_flag="y"
            ;;
        x)
            xhci_flag="y"        #$OPTARG为特殊变量，表示选项的具体参数
            ;;
        h)  
            usage
            ;;
        \?)                       #如果出现错误，则解析为?
            usage
            exit 1
            ;;
    esac
done

    killall diaggrabpro >> /dev/null 2>&1 #cordump log
    killall tcpdump >> /dev/null 2>&1 #usb pcap log
    killall auto_remove_oldfile.sh >> /dev/null  2>&1 #

    ../COMMON/addrules.sh
    check_tool tcpdump
    while true
   do
      if [ -z "$VENDORID" ];then
        VENDORID=`lsusb |grep $ModemId | awk '{print $6}' | awk -F':' '{print $2}'`
      fi
      if [ -n "$VENDORID" ]
      then
         echo "LTE device is exit $VENDORID"
         echo 1&> /dev/null
	 break
      else
         echo "LTE device no exit, please wait 3 sec and will check again PID=$$"
         sleep 3
         continue 
	 #break
      fi   
   done
    create_logsave_dir "${DATE}"
    chmod_all_file_mod
#   open modem manager's debug log
    install_drivers "${KERNEL_VERSION}"
    echo ${DATE} > ${DATE_FILE}
    echo "Capturelog.sh pcap size:$1" >> $log_file/LOG/$DATE/basic.log
    echo "$KERNEL_VERSION $BITS $VERSION" >> $log_file/LOG/$DATE/basic.log
    echo "$VERSION" >> $log_file/LOG/$DATE/basic.log
    echo "tcpdump version:" >> $log_file/LOG/$DATE/basic.log
    ../COMMON/bin/tcpdump --version >> $log_file/LOG/$DATE/basic.log
    echo "ccom version:" >> $log_file/LOG/$DATE/basic.log
    ../COMMON/bin/ccom -v >> $log_file/LOG/$DATE/basic.log
    echo "ModemManager version:" >> $log_file/LOG/$DATE/basic.log
    ModemManager -V >> $log_file/LOG/$DATE/basic.log
    echo "uname -a info:" >> $log_file/LOG/$DATE/basic.log
    uname -a >> $log_file/LOG/$DATE/basic.log
    echo "lsb-release info:" >> $log_file/LOG/$DATE/basic.log
    cat /etc/lsb-release >> $log_file/LOG/$DATE/basic.log
	echo "modemfwd info" >> $log_file/LOG/$DATE/basic.log
	modemfwd_cfg_check
	
#   clean_syslog
#   open_trace "${AT_PORT}"
    open_mmcli_debug
#	open_modemfwd_helpers_debug
	open_modemfwd_debug
	#qxdm log
	./bin/diaggrabpro -p $DiagPort -logdir /usr/local/fibocomtools/LOG/${DATE} -logsize 400 -c ./bin/data_service.cfg  -start &
  sudo dbus-monitor --system | gawk '{ print strftime("[%H:%M:%S]"), $0 }' >> $log_file/LOG/$DATE/dbus-monitor.log 2>&1 &
#	dbus-monitor --system >> $log_file/LOG/$DATE/dbus-monitor.log 2>&1 &
       
  dmesg | grep 2cb7 > 2.txt
  temp=`grep -o '[0-9]\-[0-9]' 2.txt`
  temp=${temp:0:3}
  rm 2.txt
  ls /sys/bus/usb/devices/$temp/power/ >> $log_file/LOG/$DATE/device_file.log 2>&1 &

	if [ "$xhci_flag" == "y" ];then #USB controler log
	    echo "enable xhci log capture,please wait"
        open_dynamic_log
	fi
	if [ "$ftrace_flag" == "y" ];then #内核动态执行log	
	    echo "enable ftrace log capture,please wait"
	    ../COMMON/usb-ftrace-start.sh
	fi
	capture_pcap_limit "${DATE}" $sttlog_size
    trap '{ echo "Hey, you pressed Ctrl-C.  Time to quit." ; kill_lastthread; capture_sys "${DATE}"; exit 1; }' INT
    while true
    do
	   DiskInfo=$(df -h /usr/local)
       DiskSize=`echo $DiskInfo|cut -d " " -f11`
       #echo $DiskSize
       FreeDiskSize=${DiskSize%?}
       #echo $FreeDiskSize
       if [[ $DiskLimitSize > $FreeDiskSize ]];
       then echo "Disk space limit, can not capture log"
	   kill_lastthread
	   capture_sys "${DATE}"
	   exit 1
       fi
	   sleep 1
              DUMP_ID=`lsusb |grep 05c6:900e | awk '{print $6}'`
       if [ -n "$DUMP_ID" ]
       then
            echo 1&> /dev/null 
       else
            continue
       fi
       if [ $DUMP_ID = "05c6:900e" ]
       then
	               echo "capture coredump start .........please wait"
				   ./bin/fibo_dump_collect_tool -f ../LOG/$DATE/coredump
	               echo "capture coredump end   ........."
	               sleep 1
       fi
	   
    done
}
main "$@"
