# Copyright 2020 Fibocom Wireless Inc All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
#!/bin/bash -e

VERSION="UPDATE_FW_V1.0.18"
readonly PROG="$(basename "$0")"
readonly LOG_TAG='modem-set-power'
chromeos_cfg_file="/etc/lsb-release"

# Starting from Coral Proto2, EN_PP3300_DX_LTE is controlled via this GPIO
EN_GPIO=432
readonly EN_GPIO_ON=1
readonly EN_GPIO_OFF=0

log_info() {
  logger -t "${LOG_TAG}" --id="$$" -p info "$*"
  echo "   INFO: $*" > /dev/stderr
}

log_warning() {
  logger -t "${LOG_TAG}" --id="$$" -p warn "$*"
  echo "WARNING: $*" > /dev/stderr
}

log_error() {
  logger -t "${LOG_TAG}" --id="$$" -p err "$*"
  echo "  ERROR: $*" > /dev/stderr
}

die() {
  log_error "$@"
  exit 1
}

set_modem_power() {
  local new_value="$1"

  local gpio_node=/sys/class/gpio/gpio"${EN_GPIO}"
  if [ ! -e "${gpio_node}" ]; then
    echo "${EN_GPIO}" > /sys/class/gpio/export
    [ -e "${gpio_node}" ] || die "Failed to export GPIO ${EN_GPIO}"
  fi

  local value_file="${gpio_node}"/value
  local old_value="$(cat "${value_file}")"
  if [ "${old_value}" != "${new_value}" ]; then
    echo 'out' > "${gpio_node}"/direction
    echo "${new_value}" > "${value_file}"
  fi
  old_value="$(cat "${value_file}")"
  [ "${old_value}" = "${new_value}" ] || die "Failed to update GPIO ${EN_GPIO}"
}
set_stt() {
    sleep 20
    AT_PORT=`ls /dev/ttyACM* | awk 'NR==3{print}'`
    echo "###$AT_PORT####"
    ./bin/ccom -d "AT+GTMCFWVER?" -p $AT_PORT > version.txt
    #version=`grep "AT< +GTMCFWVER:" version.txt |cut -d : -f 2 |cut -d ' ' -f 2`
    newversion=`grep "AT< +GTMCFWVER:" version.txt`
    echo "$newversion" > versionline
    version=$(cut -d : -f 2 versionline| cut -d ' ' -f 2)
    echo "$version"
    if [ "$version" == "\"18500.5001.00.03.25.18\"" ];then
        #echo "$version == \"18500.5001.00.03.25.18\",input command"
        ./bin/ccom -d "at+gtstage=0,1" -p $AT_PORT  > /dev/null 2>&1
        if [ $? -eq 0 ];then
            #echo "ccom ok"
            :
        else
            #echo "skip ccom use echo -e"
            echo -e "at+gtstage=0,1\r\n" > $AT_PORT
        fi
        sleep 5
        ./bin/ccom -d "at+xsystrace=pndefault,\"proute=oct;bb_etm=-1\"" -p $AT_PORT > /dev/null 2>&1
        if [ $? -eq 0 ];then
            #echo "ccom ok"
            :
        else
            #echo "skip ccom use echo -e"
            echo -e "at+xsystrace=pndefault,\"proute=oct;bb_etm=-1\"" -p $AT_PORT
        fi
    elif [ "$version" \< "\"18500.5001.00.03.25.18\"" ]; then
        #echo "$version < \"18500.5001.00.03.25.18\".nothing to do"
        :
    else
       : 
    fi
   rm -rf versionline
   rm -rf newversion
   rm -rf version.txt
}

# search firmware and select firmware
search_fw(){
  fw_path="$1"
  fw="$2" 
  count="$3"
  mode="$4"
  type="$5" 
  num=0
 
  echo "${num}. skip"
  for get_fw_name in $fw_path
  do
    num=`expr $num + 1`
    Fw_list[$num]="$get_fw_name"
    echo "${num}. ${get_fw_name}"
  done
  if [ $type == 0 ];then
    read -p "Please choose main fw to flash: " i
  elif [ $type == 1 ];then
    read -p "Please choose oem fw to flash: " i
  else
    read -p "Please choose carrier fw to flash: " i
  fi

  if [ ${i} != "0" ];then
    cp ${Fw_list[i]} ./
    temp_path=`pwd`/${Fw_list[i]##*/}
    xz -d ${temp_path}
    Fw_list[i]=${temp_path%%.xz*} 
  # if we choose skip, we should record it.
    fw[count]=${Fw_list[i]} 
    count=`expr $count + 1`
    echo "count: ${count}" 
  fi
}

main() {
  echo -e "########## $VERSION ###########"

  if [ `whoami` != "root" ];then
      echo "only root can run me"
      exit 1
  fi  
  #kill other process
  #killall DownloadTool
  rm -rf *.fls3
  rm -rf *.fls2

  OS_ARCH=Linux64

  CURRENT_PATH=${PWD}
  
  local fw="$1"
  local fw="$2"
  local fw="$3"
  if [ "$1" == "" ];then
    echo "1: in current folder"
    echo "2: use original path"
    read -p "Please choose fw path:" mode

    #set firmware's path
    if [ "$mode" == "1" ];then
      path="/usr/local/fibocomtools/"
    else
      path="/opt/google/modemfwd-firmware/"
    fi
    count=0
    #choose main firmware to flash
    search_fw "`find ${path} | grep 18500`" "$fw" "$count" "$mode" 0
	  #choose oem firmware to flash
    search_fw "`find ${path} | grep OEM | grep xz`" "$fw" "$count" "$mode" 1	
	  #choose carrier firmware to flash
    search_fw "`find ${path} | grep fls | grep -v OEM | grep -v 18500`" "$fw" "$count" "$mode" 2
  fi

   temp=0
   while [ "$temp" -lt "$count" ]
   do
     echo "fw path is ${fw[temp]}" 
     [ -n "${fw[temp]}" ] || die "Firmware not specified"
     [ -e "${fw[temp]}" ] || die "${fw[temp]} not found"
     temp=`expr $temp + 1`
   done

  local customer=""
  if [ ! -f "$chromeos_cfg_file" ]; then
    echo "$modemfwd_cfg_file is not exist"
	customer="other"
  else
    board_line=`cat /etc/lsb-release |grep CHROMEOS_RELEASE_BOARD`
    echo "$board_line" > board_newline
    customer=$(cut -d = -f 2 board_newline|cut -d - -f 1) 
    rm -rf  board_newline
  fi

  echo "$customer"  
  
  if [ "$customer" == "nautilus" ];then
    echo "it's samsung platform, use EN_GPIO=432"
    EN_GPIO=432
  elif [ "$customer" == "brya" ];then
    echo "it's brya platform, use EN_GPIO=488"
    EN_GPIO=488
  elif [ "$customer" == "Guybrash" ];then
    echo "it's Guybrush platform, use EN_GPIO=280"
    EN_GPIO=280
  elif [ "$customer" == "coral" ];then
    echo "it's acer platform, use EN_GPIO=395"
    EN_GPIO=395
  elif [ "$customer" == "quanta" ];then
    echo "it's quanta platform, use EN_GPIO=395"
    EN_GPIO=395
  elif [ "$customer" == "sarien" ];then
    echo "it's dell platform, use EN_GPIO=311"
    EN_GPIO=311
  elif [ "$customer" == "drallion" ];then
    echo "it's drallion platform, use EN_GPIO=466"
    EN_GPIO=466
  elif [ "$customer" == "hatch" ];then
    echo "it's hatch platform, use EN_GPIO=218"
    EN_GPIO=218
  elif [ "$customer" == "dedede" ];then
    echo "it's dedede platform, use EN_GPIO=349"
    EN_GPIO=349
  elif [ "$customer" == "zork" ];then
    echo "it's zork platform, use EN_GPIO=345"
    EN_GPIO=345
  elif [ "$customer" == "octopus" ];then
    echo "it's octopus platform, use EN_GPIO=337"
    EN_GPIO=393
    set_modem_power "${EN_GPIO_ON}"
    EN_GPIO=499
	set_modem_power "${EN_GPIO_ON}"
	EN_GPIO=337
  else
    echo "$customer customer not support"
	customer="other"
  fi
  #kill other process
  #killall DownloadTool
  #sleep 2
 
  if [ "$customer" == "other" ];then
        echo "it's other platform, use at+cfun=1,1"
        ( ./MiniDownloadTool  "${fw[0]}" "${fw[1]}" "${fw[2]}"  ) &
        sleep .5
        AT_PORT=`ls /dev/ttyACM* | awk 'NR==1{print}'`
	#fuser $AT_PORT -k
	echo "---------"
        ./bin/ccom -d "at+cfun=1,1" -p $AT_PORT > /dev/null 2>&1
	if [ $? -eq 0 ];then
		echo "ccom OK "
	else
		echo "skip ccom use echo -e"
		echo -e "at+cfun=1,1\r\n" > $AT_PORT
	fi
	echo "---------"
        #/pycom.py at+cfun=1,1 $AT_PORT
        #echo -e "at+cfun=1,1\r\n" >  $AT_PORT
        wait
  	#kill other process
        #killall DownloadTool
        echo "download END"
        exit
  fi

  set_modem_power "${EN_GPIO_OFF}"
  if [ -n "${fw[0]}" ];then
    if [ -n "${fw[1]}" ]; then
      if [ -n "${fw[2]}" ]; then 
        ( ./bin/MiniDownloadTool  "${fw[0]}" "${fw[1]}" "${fw[2]}" ) &
      else
        ( ./bin/MiniDownloadTool  "${fw[0]}" "${fw[1]}" ) &
      fi
    else
      ( ./bin/MiniDownloadTool "${fw[0]}" ) &
    fi
  else
    echo "no firmware to be flash"
  fi
  sleep .5
  set_modem_power "${EN_GPIO_ON}"
  wait

  #kill other process
  #killall DownloadTool
  echo "download END"
  echo "please wait exit"
  set_stt
  exit

}

main "$@"
