echo ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
echo :: Specify the keys and gold-key certificate here:
echo ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
GOLD_KEY_CERT=keys/GPukCert.bin
G_KEY_PRIV=keys/Gprk2048dev.key
M_KEY_PRIV=keys/Mprk2048dev.key
S_KEY_PRIV=keys/Sprk2048dev.key
PUBLIC_KEYS=keys/DevPubKeys.bin
echo ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::

TOOLS_FOLDER=tools
FLSTOOL=FlsTool
SIGN_SCRIPTS_FOLDER=scripts
TEMP_FOLDER=temp
BOOTCORE=${TEMP_FOLDER}

MODEM_FOLDER=../
# find NAND fls
INPUT_FLS_VERSION=$1
if [ -n "$2" ];then
	CUSTOMER=$2
else
	CUSTOMER=HP
fi
INPUT_FLS_NAME=${INPUT_FLS_VERSION}_NAND.fls
INPUT_FLS=$MODEM_FOLDER$INPUT_FLS_NAME
# delete "_NAND.fls" string
SIGNED_FLS=output/${INPUT_FLS_VERSION}_NAND_${CUSTOMER}_signed.fls

anERROR ()
{
echo
echo -------------------------------------------------------------------------------
echo ERRORS DETECTED... Script aborted....
echo
echo Output of failed process:
echo -------------------------------------------------------------------------------
echo
exit 1
}

echo -------------------------------------------------------------------------------
echo   Producing signed M.2 7360 Signed release
echo
echo   Gold key certificate : ${GOLD_KEY_CERT}
echo   Public keys          : ${PUBLIC_KEYS}
echo   Gold private key     : ${G_KEY_PRIV}
echo   Master private key   : ${M_KEY_PRIV}
echo   Security private key : ${S_KEY_PRIV}
echo

rm -rf ${TEMP_FOLDER}
mkdir ${TEMP_FOLDER}

echo
echo   Copying keys...
cp ${GOLD_KEY_CERT} ${TEMP_FOLDER}/Cert.bin
if [ $? -ne 0 ]; then
  anERROR
fi
cp ${G_KEY_PRIV} ${TEMP_FOLDER}/Gprk.key
if [ $? -ne 0 ]; then
  anERROR
fi
cp ${M_KEY_PRIV} ${TEMP_FOLDER}/Mprk.key
if [ $? -ne 0 ]; then
  anERROR
fi
cp ${S_KEY_PRIV} ${TEMP_FOLDER}/Sprk.key
if [ $? -ne 0 ]; then
  anERROR
fi
cp ${PUBLIC_KEYS} ${TEMP_FOLDER}/DevPubKeys.bin
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Done
echo

echo
echo   Fetching ${INPUT_FLS_NAME}_NAND.fls components from system build...
echo   Extracting ebl.fls
${TOOLS_FOLDER}/${FLSTOOL} --extract-fls --tag EBL ${INPUT_FLS} -o ${BOOTCORE}/ebl.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Extracting slb.fls
${TOOLS_FOLDER}/${FLSTOOL} --extract-fls --tag SLB ${INPUT_FLS} -o ${BOOTCORE}/slb.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Extracting psi_ram.fls
${TOOLS_FOLDER}/${FLSTOOL} --extract-fls --tag PSI_RAM ${INPUT_FLS} -o ${BOOTCORE}/psi_ram.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Extracting psi_flash.fls
${TOOLS_FOLDER}/${FLSTOOL} --extract-fls --tag PSI_FLASH ${INPUT_FLS} -o ${BOOTCORE}/psi_flash.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Extracting AENEAS_FW.fls
${TOOLS_FOLDER}/${FLSTOOL} --extract-fls --tag AENEAS ${INPUT_FLS} -o ${TEMP_FOLDER}/AENEAS_FW.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Extracting allcpus4eboot_ahb11.fls
${TOOLS_FOLDER}/${FLSTOOL} --extract-fls --tag LTE ${INPUT_FLS} -o ${TEMP_FOLDER}/allcpus4eboot_ahb11.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Extracting ${INPUT_FLS_NAME}.fls
${TOOLS_FOLDER}/${FLSTOOL} --extract-fls --tag CODE ${INPUT_FLS} -o ${TEMP_FOLDER}/${INPUT_FLS_NAME}.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Done
echo

echo
echo   Execute signing scripts...
echo   Signing psi_flash.fls
${TOOLS_FOLDER}/${FLSTOOL} --sign ${BOOTCORE}/psi_flash.fls --script ${SIGN_SCRIPTS_FOLDER}/psi_flash.signing_script_with_vid_pid_change_${CUSTOMER}.txt -o ${TEMP_FOLDER}/psi_flash_signed.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Signing slb.fls
${TOOLS_FOLDER}/${FLSTOOL} --sign ${BOOTCORE}/slb.fls --script ${SIGN_SCRIPTS_FOLDER}/slb.signing_script.txt -o ${TEMP_FOLDER}/slb_signed.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Signing psi_ram.fls
${TOOLS_FOLDER}/${FLSTOOL} --sign ${BOOTCORE}/psi_ram.fls --script ${SIGN_SCRIPTS_FOLDER}/psi_ram.signing_script.txt -o ${TEMP_FOLDER}/psi_ram_signed.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Signing ebl.fls
${TOOLS_FOLDER}/${FLSTOOL} --sign ${BOOTCORE}/ebl.fls --script ${SIGN_SCRIPTS_FOLDER}/ebl.signing_script.txt -o ${TEMP_FOLDER}/ebl_signed.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Signing AENEAS_FW.fls
${TOOLS_FOLDER}/${FLSTOOL} --sign ${TEMP_FOLDER}/AENEAS_FW.fls --script ${SIGN_SCRIPTS_FOLDER}/system_generic.txt -o ${TEMP_FOLDER}/AENEAS_FW_signed.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Signing allcpus4eboot_ahb11.fls
${TOOLS_FOLDER}/${FLSTOOL} --sign ${TEMP_FOLDER}/allcpus4eboot_ahb11.fls --script ${SIGN_SCRIPTS_FOLDER}/system_generic.txt -o ${TEMP_FOLDER}/allcpus4eboot_ahb11_signed.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Signing ${INPUT_FLS_NAME}.fls
${TOOLS_FOLDER}/${FLSTOOL} --sign ${TEMP_FOLDER}/${INPUT_FLS_NAME}.fls --script ${SIGN_SCRIPTS_FOLDER}/system_code.txt -o ${TEMP_FOLDER}/${INPUT_FLS_NAME}_signed.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Done.


echo
echo   Pack all the signed images into signed fls file...
${TOOLS_FOLDER}/${FLSTOOL} -p -o ${SIGNED_FLS} --psi=${TEMP_FOLDER}/psi_ram_signed.fls --ebl=${TEMP_FOLDER}/ebl_signed.fls --zip=${SIGN_SCRIPTS_FOLDER}/bootcore_ini.zip \
  ${TEMP_FOLDER}/psi_flash_signed.fls \
  ${TEMP_FOLDER}/slb_signed.fls \
  ${TEMP_FOLDER}/${INPUT_FLS_NAME}_signed.fls \
  ${TEMP_FOLDER}/AENEAS_FW_signed.fls \
  ${TEMP_FOLDER}/allcpus4eboot_ahb11_signed.fls \
  --replace

echo   Done.

echo
echo -------------------------------------------------------------------------------
echo Successfully produced signed release.
echo Output: ${SIGNED_FLS} and Copy to: ${MODEM_FOLDER}
echo -------------------------------------------------------------------------------
echo
rm -rf ${TEMP_FOLDER}

exit 0

