echo ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
echo :: Update the ssvid/ssid
echo ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::

TOOLS_FOLDER=tools
FLSTOOL=FlsTool
SIGN_SCRIPTS_FOLDER=scripts
TEMP_FOLDER=temp
BOOTCORE=${TEMP_FOLDER}

rm -rf ${TEMP_FOLDER}
mkdir ${TEMP_FOLDER}

MODEM_FOLDER=../
# find NAND fls
INPUT_FLS_VERSION=$1

if [ -n "$2" ];then
	CUSTOMER=$2
else
	CUSTOMER=HP
fi
INPUT_FLS_NAME=${INPUT_FLS_VERSION}_NAND.fls
INPUT_FLS=${MODEM_FOLDER}${INPUT_FLS_NAME}
# delete "_NAND.fls" string
OUTPUT_FLS=output/${INPUT_FLS_VERSION}_NAND_${CUSTOMER}.fls

anERROR ()
{
echo
echo -------------------------------------------------------------------------------
echo ERRORS DETECTED... Script aborted....
echo
echo Output of failed process:
echo -------------------------------------------------------------------------------
echo
exit 1
}


echo
echo   Fetching ${INPUT_FLS_NAME}_NAND.fls components from system build...
echo   Extracting ebl.fls
${TOOLS_FOLDER}/${FLSTOOL} --extract-fls --tag EBL ${INPUT_FLS} -o ${BOOTCORE}/ebl.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Extracting slb.fls
${TOOLS_FOLDER}/${FLSTOOL} --extract-fls --tag SLB ${INPUT_FLS} -o ${BOOTCORE}/slb.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Extracting psi_ram.fls
${TOOLS_FOLDER}/${FLSTOOL} --extract-fls --tag PSI_RAM ${INPUT_FLS} -o ${BOOTCORE}/psi_ram.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Extracting psi_flash.fls
${TOOLS_FOLDER}/${FLSTOOL} --extract-fls --tag PSI_FLASH ${INPUT_FLS} -o ${BOOTCORE}/psi_flash.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Extracting AENEAS_FW.fls
${TOOLS_FOLDER}/${FLSTOOL} --extract-fls --tag AENEAS ${INPUT_FLS} -o ${TEMP_FOLDER}/AENEAS_FW.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Extracting allcpus4eboot_ahb11.fls
${TOOLS_FOLDER}/${FLSTOOL} --extract-fls --tag LTE ${INPUT_FLS} -o ${TEMP_FOLDER}/allcpus4eboot_ahb11.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Extracting ${INPUT_FLS_NAME}.fls
${TOOLS_FOLDER}/${FLSTOOL} --extract-fls --tag CODE ${INPUT_FLS} -o ${TEMP_FOLDER}/${INPUT_FLS_NAME}.fls
if [ $? -ne 0 ]; then
  anERROR
fi
echo   Done
echo

echo
echo   Update pid and vid and Pack all the signed images into signed fls file...
# Run the signing script which replaces the VID/PID blob in the ECL structure
${TOOLS_FOLDER}/${FLSTOOL} --replace --sign ${TEMP_FOLDER}/psi_flash.fls --script ${SIGN_SCRIPTS_FOLDER}/swap_pid_vid_${CUSTOMER}.txt -o ${TEMP_FOLDER}/psi_flash_pid.fls

${TOOLS_FOLDER}/${FLSTOOL} --pack -o ${OUTPUT_FLS} --psi=${TEMP_FOLDER}/psi_ram.fls --ebl=${TEMP_FOLDER}/ebl.fls \
  ${TEMP_FOLDER}/AENEAS_FW.fls \
  ${TEMP_FOLDER}/${INPUT_FLS_NAME}.fls \
  ${TEMP_FOLDER}/slb.fls \
  ${TEMP_FOLDER}/psi_flash_pid.fls \
  ${TEMP_FOLDER}/allcpus4eboot_ahb11.fls \
  --replace

echo   Done.

echo
echo -------------------------------------------------------------------------------
echo Successfully produced signed release.
echo Output: ${OUTPUT_FLS} and Copy to: ${MODEM_FOLDER}
echo -------------------------------------------------------------------------------
echo
rm -rf ${TEMP_FOLDER}

exit 0

